﻿namespace DoxygenBugReport
{
    /// <summary>
    /// A generic base class
    /// </summary>
    /// <typeparam name="T"></typeparam>
    public class Bug<T> { }

    /// <summary>
    /// A subclass with the same name - produces a warning
    /// </summary>
    /// <remarks>
    /// This class does not connect to anything else in the class hierarchy browser, but it should appear as a child of "Bug{T}".
    /// 
    /// Warning text:
    /// Bug.cs:19: Detected potential recursive class relation between class DoxygenBugReport::Bug and base class DoxygenBugReport::Bug&lt;object&gt;!
    /// </remarks>
    public class Bug : Bug<object> { }

    /// <summary>
    /// A subclass with a different name
    /// </summary>
    /// <remarks>
    /// In the class hierarchy browser, this class appears as a child of "Bug{object}", which links to"Bug", not "Bug{T}".
    /// </remarks>
    public class BugObject : Bug<object> { }

    /// <summary>
    /// A subclass with a different name and generic type
    /// </summary>
    /// <remarks>
    /// In the class hierarchy browser, this class appears as a child of "Bug{object}", which links to"Bug", not "Bug{T}".
    /// </remarks>
    public class BugString : Bug<string> { }


    /// <summary>
    /// Another generic base class
    /// </summary>
    /// <typeparam name="T"></typeparam>
    public class Correct<T> { }

    /// <summary>
    /// A subclass with a different name, and no base name collision, illustrating expected behavior
    /// </summary>
    public class CorrectObject : Correct<object> { }

    /// <summary>
    /// A subclass with a different name, and no base name collision, illustrating expected behavior
    /// </summary>
    public class CorrectString : Correct<string> { }
}
